shimmer library
A package provides an easy way to add shimmer effect to Flutter application
Enums
- ShimmerDirection
- An enum defines all supported directions of shimmer effect
Functions
-
shimmerHighlightRect(
{required Size size, required ShimmerDirection direction, required double percent}) → Rect - Sliding rectangle used as the shader bounds for the highlight.